High-level description of visual aspects of a surface. A material is comprised of a [PipelineProgramRef], per-uniform value or texture, and a [RenderState].

See [man.ForwardPipeline] and [man.PipelineShader].